@@ -1,6 +1,6 @@
 from requests import get
 
-version = "2.0.5"
+version = "2.0.6"
 
 class TD():
     def __init__(self):
@@ -78,7 +78,3 @@ class TD():
   """
         except Exception as e:
             return "Got An Error! Report At @ProgrammerSupport\n\n{}".format(e)
-
-if __name__ == "__main__":
-            print("Welcome To TruthDarePy v{}".format(version))
-            print("Powered By @Its_IZ_PRINCE_xD")
